@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -99,6 +99,10 @@ void Preferences::reset() {
 	disable_screensaver = true;
 #endif
 
+#ifndef Q_OS_WIN
+	disable_video_filters_with_vdpau = true;
+#endif
+
 	use_soft_vol = true;
 	softvol_max = 110; // 110 = default value in mplayer
 	use_scaletempo = Detect;
@@ -115,8 +119,8 @@ void Preferences::reset() {
 	use_mc = false;
 	mc_value = 0;
 
-	loop = false;
 	osd = Seek;
+	osd_delay = 2200;
 
 	file_settings_method = "hash"; // Possible values: normal & hash
 
@@ -164,7 +168,7 @@ void Preferences::reset() {
 
 	threads = 1;
 
-	cache_for_files = 2000;
+	cache_for_files = 0;
 	cache_for_streams = 1000;
 	cache_for_dvds = 0; // not recommended to use cache for dvds
 	cache_for_vcds = 1000;
@@ -199,6 +203,8 @@ void Preferences::reset() {
 	use_new_sub_commands = Detect;
 	change_sub_scale_should_restart = Detect;
 
+	fast_load_sub = true;
+
 	// ASS styles
 	// Nothing to do, default values are given in
 	// AssStyles constructor
@@ -238,6 +244,7 @@ void Preferences::reset() {
 	log_smplayer = true;
 	log_filter = ".*";
 	verbose_log = false;
+	save_smplayer_log = false;
 
     //mplayer log autosaving
     autosave_mplayer_log = false;
@@ -284,7 +291,6 @@ void Preferences::reset() {
 	style="";
 #endif
 
-	show_frame_counter = FALSE;
 	show_motion_vectors = false;
 
 #if DVDNAV_SUPPORT
@@ -299,6 +305,7 @@ void Preferences::reset() {
 	mouse_xbutton2_click_function = "";
 	wheel_function = Seeking;
 	wheel_function_cycle = Seeking | Volume | Zoom | ChangeSpeed;
+	wheel_function_seeking_reverse = false;
 
 	seeking1 = 10;
 	seeking2 = 60;
@@ -309,6 +316,9 @@ void Preferences::reset() {
 #if ENABLE_DELAYED_DRAGGING
 	time_slider_drag_delay = 100;
 #endif
+#if SEEKBAR_RESOLUTION
+	relative_seeking = true;
+#endif
 
 	language = "";
 	iconset = "";
@@ -385,7 +395,7 @@ void Preferences::reset() {
 
 	initial_audio_equalizer << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0;
 
-	initial_panscan_factor = 1.0;
+	initial_zoom_factor = 1.0;
 	initial_sub_pos = 100; // 100%
 
 	initial_postprocessing = false;
@@ -467,7 +477,7 @@ void Preferences::save() {
 
 	set->setValue("mplayer_bin", mplayer_bin);
 	set->setValue("driver/vo", vo);
-	set->setValue("driver/ao", ao);
+	set->setValue("driver/audio_output", ao);
 
 	set->setValue("use_screenshot", use_screenshot);
 	set->setValue("screenshot_directory", screenshot_directory);
@@ -492,6 +502,10 @@ void Preferences::save() {
 	set->setValue("disable_screensaver", disable_screensaver);
 #endif
 
+#ifndef Q_OS_WIN
+	set->setValue("disable_video_filters_with_vdpau", disable_video_filters_with_vdpau);
+#endif
+
 	set->setValue("use_soft_vol", use_soft_vol);
 	set->setValue("softvol_max", softvol_max);
 	set->setValue("use_scaletempo", use_scaletempo);
@@ -508,8 +522,8 @@ void Preferences::save() {
 	set->setValue("use_mc", use_mc);
 	set->setValue("mc_value", mc_value);
 
-	set->setValue("loop", loop);
 	set->setValue("osd", osd);
+	set->setValue("osd_delay", osd_delay);
 
 	set->setValue("file_settings_method", file_settings_method);
 
@@ -597,6 +611,8 @@ void Preferences::save() {
 	set->setValue("use_new_sub_commands", use_new_sub_commands);
 	set->setValue("change_sub_scale_should_restart", change_sub_scale_should_restart);
 
+	set->setValue("fast_load_sub", fast_load_sub);
+
 	// ASS styles
 	ass_styles.save(set);
 	set->setValue("force_ass_styles", force_ass_styles);
@@ -635,6 +651,7 @@ void Preferences::save() {
 	set->setValue("log_smplayer", log_smplayer);
 	set->setValue("log_filter", log_filter);
 	set->setValue("verbose_log", verbose_log);
+	set->setValue("save_smplayer_log", save_smplayer_log);
 
     //mplayer log autosaving
     set->setValue("autosave_mplayer_log", autosave_mplayer_log);
@@ -680,7 +697,6 @@ void Preferences::save() {
 	set->setValue("style", style);
 #endif
 
-	set->setValue("show_frame_counter", show_frame_counter);
 	set->setValue("show_motion_vectors", show_motion_vectors);
 
 	set->setValue("mouse_left_click_function", mouse_left_click_function);
@@ -691,6 +707,7 @@ void Preferences::save() {
 	set->setValue("mouse_xbutton2_click_function", mouse_xbutton2_click_function);
 	set->setValue("mouse_wheel_function", wheel_function);
 	set->setValue("wheel_function_cycle", (int) wheel_function_cycle);
+	set->setValue("wheel_function_seeking_reverse", wheel_function_seeking_reverse);
 
 	set->setValue("seeking1", seeking1);
 	set->setValue("seeking2", seeking2);
@@ -701,6 +718,9 @@ void Preferences::save() {
 #if ENABLE_DELAYED_DRAGGING
 	set->setValue("time_slider_drag_delay", time_slider_drag_delay);
 #endif
+#if SEEKBAR_RESOLUTION
+	set->setValue("relative_seeking", relative_seeking);
+#endif
 
 	set->setValue("language", language);
 	set->setValue("iconset", iconset);
@@ -779,7 +799,7 @@ void Preferences::save() {
 
 	set->setValue("initial_audio_equalizer", initial_audio_equalizer);
 
-	set->setValue("initial_panscan_factor", initial_panscan_factor);
+	set->setValue("initial_zoom_factor", initial_zoom_factor);
 	set->setValue("initial_sub_pos", initial_sub_pos);
 
 	set->setValue("initial_volnorm", initial_volnorm);
@@ -869,7 +889,7 @@ void Preferences::load() {
 
 	mplayer_bin = set->value("mplayer_bin", mplayer_bin).toString();
 	vo = set->value("driver/vo", vo).toString();
-	ao = set->value("driver/ao", ao).toString();
+	ao = set->value("driver/audio_output", ao).toString();
 
 	use_screenshot = set->value("use_screenshot", use_screenshot).toBool();
 	screenshot_directory = set->value("screenshot_directory", screenshot_directory).toString();
@@ -895,6 +915,10 @@ void Preferences::load() {
 	disable_screensaver = set->value("disable_screensaver", disable_screensaver).toBool();
 #endif
 
+#ifndef Q_OS_WIN
+	disable_video_filters_with_vdpau = set->value("disable_video_filters_with_vdpau", disable_video_filters_with_vdpau).toBool();
+#endif
+
 	use_soft_vol = set->value("use_soft_vol", use_soft_vol).toBool();
 	softvol_max = set->value("softvol_max", softvol_max).toInt();
 	use_scaletempo = (OptionState) set->value("use_scaletempo", use_scaletempo).toInt();
@@ -911,8 +935,8 @@ void Preferences::load() {
 	use_mc = set->value("use_mc", use_mc).toBool();
 	mc_value = set->value("mc_value", mc_value).toDouble();
 
-	loop = set->value("loop", loop).toBool();
 	osd = set->value("osd", osd).toInt();
+	osd_delay = set->value("osd_delay", osd_delay).toInt();
 
 	file_settings_method = set->value("file_settings_method", file_settings_method).toString();
 
@@ -1001,6 +1025,8 @@ void Preferences::load() {
 	use_new_sub_commands = (OptionState) set->value("use_new_sub_commands", use_new_sub_commands).toInt();
 	change_sub_scale_should_restart = (OptionState) set->value("change_sub_scale_should_restart", change_sub_scale_should_restart).toInt();
 
+	fast_load_sub = set->value("fast_load_sub", fast_load_sub).toBool();
+
 	// ASS styles
 	ass_styles.load(set);
 	force_ass_styles = set->value("force_ass_styles", force_ass_styles).toBool();
@@ -1044,6 +1070,7 @@ void Preferences::load() {
 	log_smplayer = set->value("log_smplayer", log_smplayer).toBool();
 	log_filter = set->value("log_filter", log_filter).toString();
 	verbose_log = set->value("verbose_log", verbose_log).toBool();
+	save_smplayer_log = set->value("save_smplayer_log", save_smplayer_log).toBool();
 
     //mplayer log autosaving
     autosave_mplayer_log = set->value("autosave_mplayer_log", autosave_mplayer_log).toBool();
@@ -1087,7 +1114,6 @@ void Preferences::load() {
 	style = set->value("style", style).toString();
 #endif
 
-	show_frame_counter = set->value("show_frame_counter", show_frame_counter).toBool();
 	show_motion_vectors = set->value("show_motion_vectors", show_motion_vectors).toBool();
 
 	mouse_left_click_function = set->value("mouse_left_click_function", mouse_left_click_function).toString();
@@ -1099,6 +1125,7 @@ void Preferences::load() {
 	wheel_function = set->value("mouse_wheel_function", wheel_function).toInt();
 	int wheel_function_cycle_int = set->value("wheel_function_cycle", (int) wheel_function_cycle).toInt();
 	wheel_function_cycle = QFlags<Preferences::WheelFunctions> (QFlag(wheel_function_cycle_int));
+	wheel_function_seeking_reverse = set->value("wheel_function_seeking_reverse", wheel_function_seeking_reverse).toBool();
 
 	seeking1 = set->value("seeking1", seeking1).toInt();
 	seeking2 = set->value("seeking2", seeking2).toInt();
@@ -1109,6 +1136,9 @@ void Preferences::load() {
 #if ENABLE_DELAYED_DRAGGING
 	time_slider_drag_delay = set->value("time_slider_drag_delay", time_slider_drag_delay).toInt();
 #endif
+#if SEEKBAR_RESOLUTION
+	relative_seeking = set->value("relative_seeking", relative_seeking).toBool();
+#endif
 
 	language = set->value("language", language).toString();
 	iconset= set->value("iconset", iconset).toString();
@@ -1188,7 +1218,7 @@ void Preferences::load() {
 
 	initial_audio_equalizer = set->value("initial_audio_equalizer", initial_audio_equalizer).toList();
 
-	initial_panscan_factor = set->value("initial_panscan_factor", initial_panscan_factor).toDouble();
+	initial_zoom_factor = set->value("initial_zoom_factor", initial_zoom_factor).toDouble();
 	initial_sub_pos = set->value("initial_sub_pos", initial_sub_pos).toInt();
 
 	initial_volnorm = set->value("initial_volnorm", initial_volnorm).toBool();
@@ -1247,10 +1277,13 @@ void Preferences::load() {
        ******* */
 
 	set->beginGroup("history");
+
+	history_recents->setMaxItems( set->value("recents/max_items", history_recents->maxItems()).toInt() );
 	history_recents->fromStringList( set->value("recents", history_recents->toStringList()).toStringList() );
-	history_recents->setMaxItems( set->value("recents/max_items", history_recents->maxItems()).toInt() );;
+
+	history_urls->setMaxItems( set->value("urls/max_items", history_urls->maxItems()).toInt() );
 	history_urls->fromStringList( set->value("urls", history_urls->toStringList()).toStringList() );
-	history_urls->setMaxItems( set->value("urls/max_items", history_urls->maxItems()).toInt() );;
+
 	set->endGroup(); // history
 
 
